==> csx600_m512_le_base_RHE4_64-2.24.tgz: opt/clearspeed/csx600_m512_le/examples/csdft/1D/single/complex/performance/timing.h <==
/*
 *
 *     Copyright (c) 2006, ClearSpeed Technology plc. All rights reserved.
 *
 * This material is provided "as is", with absolutely no warranty expressed or
 * implied. Any use is at your own risk. Permission to use or copy this software
 * for any purpose is hereby granted without fee, provided the above notices are
 * retained on all copies. Permission to modify the code and to distribute
 * modified code is granted, provided the above notices are retained, and a
 * notice that the code was modified is included with the above copyright notice.
 *
 */

#ifndef _COMMON_GENERIC_UNITIME_H_
#define _COMMON_GENERIC_UNITIME_H_

#include <assert.h>
#include <stdio.h>


#ifdef __cplusplus
extern "C" {
#endif


#ifdef _WIN32
// Reduce the amount of Windows stuff we pull in
# define WINDOWS_LEAN_AND_MEAN
# include "Windows.h"
//  typedef DWORD UNITIME_T;
  typedef LARGE_INTEGER UniTime;
#else
# include <sys/time.h>
  typedef struct timeval UniTime;
#endif

/**
 * Gets the current time in a system-dependent manner (may be clock ticks,
 * may be milliseconds - use utGetMicroseconds() and utGetMilliseconds()
 * to get differences between timing results
 *
 * @param ret - pointer to UniTime type, where timing result is to be stored
 * @return 0 for success, !=0 for failure.
 */
int utGetTimeRaw( UniTime* ret );

/**
 * Returns difference between two timer values in microseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in microseconds
 */
int utGetMicrosecondsDiff( UniTime* start , UniTime* end );

/**
 * Returns difference between two timer values in milliseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in milliseconds
 */
int utGetMillisecondsDiff( UniTime* start , UniTime* end );
int utGetMilliseconds( UniTime* start , UniTime* end );

/**
 * Returns the UniTime value in microseconds.
 */
int utGetMicroseconds( UniTime* time );

/**
 * Cross-platform Sleep...
 *
 * Sleeps the given number of seconds.
 */
#ifdef _WIN32
// Note that WIN32 sleeps in terms of milliseconds, not seconds
# define CS_UT_SLEEP(s) Sleep((s) * 1000)
#else // _WIN32
# include <unistd.h>
# define CS_UT_SLEEP(s) sleep(s)
#endif // _WIN32

#ifdef __cplusplus
}
#endif

#endif /* _COMMON_GENERIC_UNITIME_H_ */



/**
 * Note if we've already initialised the timing code; e.g. Windows
 * needs to discover the number of clocks per timer tick...
 */
static int _utInitialised = 0;

#ifdef _WIN32
  static LARGE_INTEGER  timer_frequency;
#endif // _WIN32


/**
 * Sneaky singleton code - this is called once per usage of the timer
 * functions, to remove the overhead of repeatedly reinitialising
 * any system-level support.
 *
 * Other option is to expose this function, but then if someone forgets
 * the initialise statement, or if its called multiple times...
 */
static int _InitialiseTimer()
{
    if (_utInitialised)
    {
        return 0;
    }

#ifdef _WIN32
  if (!QueryPerformanceFrequency(&timer_frequency))
  {
        assert(0);
  }
#endif // _WIN32

    _utInitialised = 1;

    return 1;
}


/**
 * Gets the current time in a system-dependent manner (may be clock ticks,
 * may be milliseconds - use utGetMicroseconds() and utGetMilliseconds()
 * to get differences between timing results
 *
 * @param ret - pointer to UniTime type, where timing result is to be stored
 * @return 0 for success, !=0 for failure.
 */
int utGetTimeRaw( UniTime* ret )
{
#ifdef _WIN32
    if (!QueryPerformanceCounter(ret))
    {
      // Error!
        assert(0);

        return 0;
    }

    return 1;       // no errors detected, so return != 0
#else
      return gettimeofday(ret, NULL);
#endif
}


/**
 * Returns difference between two timer values in microseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in microseconds
 */
int utGetMicrosecondsDiff( UniTime* start , UniTime* end )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = end->QuadPart - start->QuadPart;

        result.QuadPart *= 1000000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(end->tv_sec - start->tv_sec)*1000000 + (int)(end->tv_usec - start->tv_usec);
#endif
}

/**
 * Returns difference between two timer values in milliseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in milliseconds
 */

int utGetMillisecondsDiff( UniTime* start , UniTime* end )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = end->QuadPart - start->QuadPart;

        result.QuadPart *= 1000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(end->tv_sec - start->tv_sec)*1000 + (int)(end->tv_usec - start->tv_usec)/1000 ;
#endif
}

/* Include old symbol for compatibility */
int utGetMilliseconds( UniTime* start , UniTime* end )
{
  return utGetMillisecondsDiff(start, end);
}


/**
 * Returns the UniTime value in microseconds.
 */
int utGetMicroseconds( UniTime* time )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = time->QuadPart;
        result.QuadPart *= 1000000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(time->tv_sec)*1000000 + (int)(time->tv_usec);
#endif
}

==> csx600_m512_le_base_RHE4_64-2.50.tgz: opt/clearspeed/csx600_m512_le/examples/csdft/1D/single/complex/performance/timing.h <==
//
//
//      Copyright (c) ClearSpeed Technology Ltd 2001-2006.
//      All rights reserved.
//
// The following constitutes CONFIDENTIAL & PROPRIETARY SOURCE CODE of
// ClearSpeed Technology Ltd and the contents of this file may not be:
// disclosed to any third party; copied; or duplicated, whether in whole
// or in part, without the express written permission of a company
// Executive Director of ClearSpeed Technology Ltd.
//
// Author: mh
// Date  : 17-feb-2006
// Descr : wrapper for portable timing routines


#ifndef _COMMON_GENERIC_UNITIME_H_
#define _COMMON_GENERIC_UNITIME_H_


#ifdef __cplusplus
extern "C" {
#endif


#ifdef _WIN32
  // Reduce the amount of Windows bumpf we pull in - we don't need the GUI!
# define WINDOWS_LEAN_AND_MEAN
# include "Windows.h"
//  typedef DWORD UNITIME_T;
  typedef LARGE_INTEGER UniTime;
#else
# include <sys/time.h>
  typedef struct timeval UniTime;
#endif

/**
 * Gets the current time in a system-dependent manner (may be clock ticks,
 * may be milliseconds - use utGetMicroseconds() and utGetMilliseconds()
 * to get differences between timing results
 *
 * @param ret - pointer to UniTime type, where timing result is to be stored
 * @return 0 for success, !=0 for failure.
 */
int utGetTimeRaw( UniTime* ret );

/**
 * Returns difference between two timer values in microseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in microseconds
 */
int utGetMicrosecondsDiff( UniTime* start , UniTime* end );

/**
 * Returns difference between two timer values in milliseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in milliseconds
 */
int utGetMillisecondsDiff( UniTime* start , UniTime* end );
int utGetMilliseconds( UniTime* start , UniTime* end );

/**
 * Returns the UniTime value in microseconds.
 */
int utGetMicroseconds( UniTime* time );

/**
 * Cross-platform Sleep...
 *
 * Sleeps the given number of seconds.
 */
#ifdef _WIN32
// Note that WIN32 sleeps in terms of milliseconds, not seconds
# define CS_UT_SLEEP(s) Sleep((s) * 1000)
#else // _WIN32
# include <unistd.h>
# define CS_UT_SLEEP(s) sleep(s)
#endif // _WIN32

#ifdef __cplusplus
}
#endif

#endif /* _COMMON_GENERIC_UNITIME_H_ */
//
//
//      Copyright (c) ClearSpeed Technology Ltd 2001.
//      All rights reserved.
//
// The following constitutes CONFIDENTIAL & PROPRIETARY SOURCE CODE of
// ClearSpeed Technology Ltd and the contents of this file may not be:
// disclosed to any third party; copied; or duplicated, whether in whole
// or in part, without the express written permission of a company
// Executive Director of ClearSpeed Technology Ltd.
//
//

// Original version by Michal

// 21 Feb 2006 - iang - changed to match coding standards, uses high resolution
//               windows timers.

//#include "../include/__BlasLibWindowsReportError.h"


#include <assert.h>
#include <stdio.h>

/**
 * Note if we've already initialised the timing code; e.g. Windows
 * needs to discover the number of clocks per timer tick...
 */
static int _utInitialised = 0;

#ifdef _WIN32
  static LARGE_INTEGER  timer_frequency;
#endif // _WIN32


/**
 * Sneaky singleton code - this is called once per usage of the timer
 * functions, to remove the overhead of repeatedly reinitialising
 * any system-level support.
 *
 * Other option is to expose this function, but then if someone forgets
 * the initialise statement, or if its called multiple times...
 */
static int _InitialiseTimer()
{
    if (_utInitialised)
    {
        return 0;
    }

#ifdef _WIN32
  if (!QueryPerformanceFrequency(&timer_frequency))
  {
//    __BlasLibWindowsReportError("QueryPerformanceFrequency(timer_frequency) failed");
        assert(0);
  }
#endif // _WIN32

    _utInitialised = 1;

    return 1;
}


/**
 * Gets the current time in a system-dependent manner (may be clock ticks,
 * may be milliseconds - use utGetMicroseconds() and utGetMilliseconds()
 * to get differences between timing results
 *
 * @param ret - pointer to UniTime type, where timing result is to be stored
 * @return 0 for success, !=0 for failure.
 */
int utGetTimeRaw( UniTime* ret )
{
#ifdef _WIN32
    if (!QueryPerformanceCounter(ret))
    {
      // Error!
//      __BlasLibWindowsReportError("QueryPerformanceCounter() failed");
        assert(0);

        return 0;
    }

    return 1;       // no errors detected, so return != 0
#else
      return gettimeofday(ret, NULL);
#endif
}


/**
 * Returns difference between two timer values in microseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in microseconds
 */
int utGetMicrosecondsDiff( UniTime* start , UniTime* end )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = end->QuadPart - start->QuadPart;

        result.QuadPart *= 1000000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(end->tv_sec - start->tv_sec)*1000000 + (int)(end->tv_usec - start->tv_usec);
#endif
}

/**
 * Returns difference between two timer values in milliseconds.
 *
 * @param start Start time we want to compare against
 * @param end End time we want to compare against
 *
 * @return difference between start and end times in milliseconds
 */

int utGetMillisecondsDiff( UniTime* start , UniTime* end )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = end->QuadPart - start->QuadPart;

        result.QuadPart *= 1000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(end->tv_sec - start->tv_sec)*1000 + (int)(end->tv_usec - start->tv_usec)/1000 ;
#endif
}

/* Include old symbol for compatibility */
int utGetMilliseconds( UniTime* start , UniTime* end )
{
  return utGetMillisecondsDiff(start, end);
}


/**
 * Returns the UniTime value in microseconds.
 */
int utGetMicroseconds( UniTime* time )
{
    if (!_utInitialised)
    {
        _InitialiseTimer();
    }

#ifdef _WIN32
    {
        // Long-hand declaration to sanity check the order of operations;
        // we don't want early rounding when dealing with integers!!!
      LARGE_INTEGER result;

        result.QuadPart = time->QuadPart;
        result.QuadPart *= 1000000;
        result.QuadPart /= timer_frequency.QuadPart;

        return (int)result.QuadPart;
    }
#else
        return (int)(time->tv_sec)*1000000 + (int)(time->tv_usec);
#endif
}
